@@ -20,8 +20,6 @@
 #
 """Module attribute provides class Attribute."""
 
-from csv import reader as csv_reader
-
 from ajsonapi.field import Field
 
 
@@ -36,11 +34,12 @@ class Attribute(Field):
         self.nullable = nullable
         self.default = default
 
+    def filter_values(self, values):
+        sql_values = [self.type_.sql(value) for value in values]
+        return ','.join(sql_values)
+
     def filter_condition(self, values):
-        sql_values = [
-            self.type_.sql(value) for value in next(csv_reader([values]))
-        ]
-        return f"{self.name} IN ({','.join(sql_values)})"
+        return values
 
     def sql(self):
         """Creates the SQL column definition for this attribute.
