@@ -24,7 +24,7 @@ from abc import abstractmethod
 
 from asyncpg.exceptions import ForeignKeyViolationError
 
-from ajsonapi.conversions import id_name_to_number, id_number_to_name
+from ajsonapi.conversions import id_number_to_name
 from ajsonapi.errors import (
     DocumentDataInvalidRelationshipTypeError,
     DocumentDataMalformedRelationshipDataError,
@@ -37,6 +37,7 @@ from ajsonapi.exceptions import NonexistentRelationshipIdError
 from ajsonapi.field import Field
 from ajsonapi.id_value import IdValue
 from ajsonapi.logging import log
+from ajsonapi.types import Uuid
 from ajsonapi.uri.related import (
     ManyToManyRelatedResource,
     ManyToOneRelatedResource,
@@ -70,6 +71,7 @@ class Relationship(Field):
         self.name = None  # Overridden in Table.__init_subclass__
         self.reverse = None  # Overridden in Table.__init_subclass__
         self.collection = None  # Overriden in Table.__init_subclass__
+        self.type_ = Uuid
 
     @abstractmethod
     def make_uri_relationship(self, collection, id_):
@@ -107,6 +109,9 @@ class Relationship(Field):
         object.
         """
 
+    def filter_values(self, values):
+        return ','.join(f"'{str(uuid)}'" for uuid in values)
+
 
 class LocalRelationship(Relationship):
     """A relationship with a local foreign key."""
@@ -117,9 +122,7 @@ class LocalRelationship(Relationship):
         self.nullable = nullable
 
     def filter_condition(self, values):
-        uuids = ','.join(
-            f"'{id_name_to_number(uuid)}'" for uuid in values.split(','))
-        return f'{self.lfkey} IN ({uuids})'
+        return f'{self.lfkey} IN ({values})'
 
     @abstractmethod
     def is_reverse(self, other):
@@ -315,7 +318,9 @@ class OneToOneLocalRelationship(LocalRelationship, ToOneRelationship):
             partial = ''
         else:
             if filters:
-                where_clause = f' WHERE {" AND ".join(filters)}'
+                where_clause = (
+                    f' WHERE '
+                    f'{" AND ".join(filters.conditions(self.collection))}')
             else:
                 where_clause = ''
 
@@ -355,10 +360,8 @@ class OneToOneRemoteRelationship(ToOneRelationship):
         self.rfkey = rfkey
 
     def filter_condition(self, values):
-        uuids = ','.join(
-            f"'{id_name_to_number(uuid)}'" for uuid in values.split(','))
         return (f'id IN (SELECT {self.rfkey} from data.{self.rtable.name} '
-                f'WHERE id IN ({uuids}))')
+                f'WHERE id IN ({values}))')
 
     def make_uri_relationship(self, collection, id_):
         return UriOneToOneRemoteRelationship(collection, id_, self)
@@ -378,7 +381,9 @@ class OneToOneRemoteRelationship(ToOneRelationship):
             where = f'WHERE {self.rfkey} IS NOT NULL'
         else:
             if filters:
-                where_clause = f' WHERE {" AND ".join(filters)}'
+                where_clause = (
+                    f' WHERE '
+                    f'{" AND ".join(filters.conditions(self.collection))}')
             else:
                 where_clause = ''
 
@@ -750,10 +755,8 @@ class OneToManyRelationship(ToManyRelationship):
         self.rfkey = rfkey
 
     def filter_condition(self, values):
-        uuids = ','.join(
-            f"'{id_name_to_number(uuid)}'" for uuid in values.split(','))
         return (f'id IN (SELECT {self.rfkey} FROM data.{self.rtable.name} '
-                f'WHERE id in ({uuids}))')
+                f'WHERE id in ({values}))')
 
     def make_uri_relationship(self, collection, id_):
         return UriOneToManyRelationship(collection, id_, self)
@@ -773,7 +776,9 @@ class OneToManyRelationship(ToManyRelationship):
             where = f'WHERE {self.rfkey} IS NOT NULL'
         else:
             if filters:
-                where_clause = f' WHERE {" AND ".join(filters)}'
+                where_clause = (
+                    f' WHERE '
+                    f'{" AND ".join(filters.conditions(self.collection))}')
             else:
                 where_clause = ''
 
@@ -1219,10 +1224,8 @@ class ManyToManyRelationship(ToManyRelationship):
         self.rafkey = rafkey
 
     def filter_condition(self, values):
-        uuids = ','.join(
-            f"'{id_name_to_number(uuid)}'" for uuid in values.split(','))
         return (f'id IN (SELECT {self.lafkey} FROM data.{self.atable.name} '
-                f'WHERE {self.rafkey} IN ({uuids}))')
+                f'WHERE {self.rafkey} IN ({values}))')
 
     def make_uri_relationship(self, collection, id_):
         return UriManyToManyRelationship(collection, id_, self)
